==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1beta1CertificateSigningRequestConditionFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import org.joda.time.DateTime;

public class V1beta1CertificateSigningRequestConditionFluentImpl<A extends V1beta1CertificateSigningRequestConditionFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1CertificateSigningRequestConditionFluent<A>{

    private DateTime lastUpdateTime;
    private String message;
    private String reason;
    private String type;

    public V1beta1CertificateSigningRequestConditionFluentImpl(){
    }
    public V1beta1CertificateSigningRequestConditionFluentImpl(V1beta1CertificateSigningRequestCondition instance){
            this.withLastUpdateTime(instance.getLastUpdateTime());

            this.withMessage(instance.getMessage());

            this.withReason(instance.getReason());

            this.withType(instance.getType());

    }

    public DateTime getLastUpdateTime(){
            return this.lastUpdateTime;
    }

    public A withLastUpdateTime(DateTime lastUpdateTime){
            this.lastUpdateTime=lastUpdateTime; return (A) this;
    }

    public Boolean hasLastUpdateTime(){
            return this.lastUpdateTime != null;
    }

    public A withNewLastUpdateTime(int arg0,int arg1,int arg2,int arg3,int arg4){
            return (A)withLastUpdateTime(new DateTime(arg0, arg1, arg2, arg3, arg4));
    }

    public A withNewLastUpdateTime(long arg0){
            return (A)withLastUpdateTime(new DateTime(arg0));
    }

    public A withNewLastUpdateTime(Object arg0){
            return (A)withLastUpdateTime(new DateTime(arg0));
    }

    public String getMessage(){
            return this.message;
    }

    public A withMessage(String message){
            this.message=message; return (A) this;
    }

    public Boolean hasMessage(){
            return this.message != null;
    }

    public String getReason(){
            return this.reason;
    }

    public A withReason(String reason){
            this.reason=reason; return (A) this;
    }

    public Boolean hasReason(){
            return this.reason != null;
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1CertificateSigningRequestConditionFluentImpl that = (V1beta1CertificateSigningRequestConditionFluentImpl) o;
            if (lastUpdateTime != null ? !lastUpdateTime.equals(that.lastUpdateTime) :that.lastUpdateTime != null) return false;
            if (message != null ? !message.equals(that.message) :that.message != null) return false;
            if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1CertificateSigningRequestConditionFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import org.joda.time.DateTime;

public class V1beta1CertificateSigningRequestConditionFluentImpl<A extends V1beta1CertificateSigningRequestConditionFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1CertificateSigningRequestConditionFluent<A>{

    private DateTime lastUpdateTime;
    private String message;
    private String reason;
    private String type;

    public V1beta1CertificateSigningRequestConditionFluentImpl(){
    }
    public V1beta1CertificateSigningRequestConditionFluentImpl(V1beta1CertificateSigningRequestCondition instance){
            this.withLastUpdateTime(instance.getLastUpdateTime());

            this.withMessage(instance.getMessage());

            this.withReason(instance.getReason());

            this.withType(instance.getType());

    }

    public DateTime getLastUpdateTime(){
            return this.lastUpdateTime;
    }

    public A withLastUpdateTime(DateTime lastUpdateTime){
            this.lastUpdateTime=lastUpdateTime; return (A) this;
    }

    public Boolean hasLastUpdateTime(){
            return this.lastUpdateTime != null;
    }

    public A withNewLastUpdateTime(int arg0,int arg1,int arg2,int arg3,int arg4){
            return (A)withLastUpdateTime(new DateTime(arg0, arg1, arg2, arg3, arg4));
    }

    public A withNewLastUpdateTime(Object arg0){
            return (A)withLastUpdateTime(new DateTime(arg0));
    }

    public A withNewLastUpdateTime(long arg0){
            return (A)withLastUpdateTime(new DateTime(arg0));
    }

    public String getMessage(){
            return this.message;
    }

    public A withMessage(String message){
            this.message=message; return (A) this;
    }

    public Boolean hasMessage(){
            return this.message != null;
    }

    public A withNewMessage(String arg1){
            return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuilder arg1){
            return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1){
            return (A)withMessage(new String(arg1));
    }

    public String getReason(){
            return this.reason;
    }

    public A withReason(String reason){
            this.reason=reason; return (A) this;
    }

    public Boolean hasReason(){
            return this.reason != null;
    }

    public A withNewReason(String arg1){
            return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuilder arg1){
            return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuffer arg1){
            return (A)withReason(new String(arg1));
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public A withNewType(String arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1){
            return (A)withType(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1CertificateSigningRequestConditionFluentImpl that = (V1beta1CertificateSigningRequestConditionFluentImpl) o;
            if (lastUpdateTime != null ? !lastUpdateTime.equals(that.lastUpdateTime) :that.lastUpdateTime != null) return false;
            if (message != null ? !message.equals(that.message) :that.message != null) return false;
            if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}
